==> omemo-dr-0.99.0.tar.gz: omemo-dr-0.99.0/tests/kdf/test_hkdf.py <==
import unittest

from omemo_dr.kdf.hkdf import HKDF


class HKDFTest(unittest.TestCase):
    def test_vectorV3(self):
        ikm = bytearray(
            [
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
            ]
        )

        salt = bytearray(
            [
                0x00,
                0x01,
                0x02,
                0x03,
                0x04,
                0x05,
                0x06,
                0x07,
                0x08,
                0x09,
                0x0A,
                0x0B,
                0x0C,
            ]
        )

        info = bytearray([0xF0, 0xF1, 0xF2, 0xF3, 0xF4, 0xF5, 0xF6, 0xF7, 0xF8, 0xF9])

        okm = bytearray(
            [
                0x3C,
                0xB2,
                0x5F,
                0x25,
                0xFA,
                0xAC,
                0xD5,
                0x7A,
                0x90,
                0x43,
                0x4F,
                0x64,
                0xD0,
                0x36,
                0x2F,
                0x2A,
                0x2D,
                0x2D,
                0x0A,
                0x90,
                0xCF,
                0x1A,
                0x5A,
                0x4C,
                0x5D,
                0xB0,
                0x2D,
                0x56,
                0xEC,
                0xC4,
                0xC5,
                0xBF,
                0x34,
                0x00,
                0x72,
                0x08,
                0xD5,
                0xB8,
                0x87,
                0x18,
                0x58,
                0x65,
            ]
        )

        actualOutput = HKDF(3).deriveSecrets(ikm, info, 42, salt=salt)
        self.assertEqual(okm, actualOutput)

    def test_vectorLongV3(self):
        ikm = bytearray(
            [
                0x00,
                0x01,
                0x02,
                0x03,
                0x04,
                0x05,
                0x06,
                0x07,
                0x08,
                0x09,
                0x0A,
                0x0B,
                0x0C,
                0x0D,
                0x0E,
                0x0F,
                0x10,
                0x11,
                0x12,
                0x13,
                0x14,
                0x15,
                0x16,
                0x17,
                0x18,
                0x19,
                0x1A,
                0x1B,
                0x1C,
                0x1D,
                0x1E,
                0x1F,
                0x20,
                0x21,
                0x22,
                0x23,
                0x24,
                0x25,
                0x26,
                0x27,
                0x28,
                0x29,
                0x2A,
                0x2B,
                0x2C,
                0x2D,
                0x2E,
                0x2F,
                0x30,
                0x31,
                0x32,
                0x33,
                0x34,
                0x35,
                0x36,
                0x37,
                0x38,
                0x39,
                0x3A,
                0x3B,
                0x3C,
                0x3D,
                0x3E,
                0x3F,
                0x40,
                0x41,
                0x42,
                0x43,
                0x44,
                0x45,
                0x46,
                0x47,
                0x48,
                0x49,
                0x4A,
                0x4B,
                0x4C,
                0x4D,
                0x4E,
                0x4F,
            ]
        )

        salt = bytearray(
            [
                0x60,
                0x61,
                0x62,
                0x63,
                0x64,
                0x65,
                0x66,
                0x67,
                0x68,
                0x69,
                0x6A,
                0x6B,
                0x6C,
                0x6D,
                0x6E,
                0x6F,
                0x70,
                0x71,
                0x72,
                0x73,
                0x74,
                0x75,
                0x76,
                0x77,
                0x78,
                0x79,
                0x7A,
                0x7B,
                0x7C,
                0x7D,
                0x7E,
                0x7F,
                0x80,
                0x81,
                0x82,
                0x83,
                0x84,
                0x85,
                0x86,
                0x87,
                0x88,
                0x89,
                0x8A,
                0x8B,
                0x8C,
                0x8D,
                0x8E,
                0x8F,
                0x90,
                0x91,
                0x92,
                0x93,
                0x94,
                0x95,
                0x96,
                0x97,
                0x98,
                0x99,
                0x9A,
                0x9B,
                0x9C,
                0x9D,
                0x9E,
                0x9F,
                0xA0,
                0xA1,
                0xA2,
                0xA3,
                0xA4,
                0xA5,
                0xA6,
                0xA7,
                0xA8,
                0xA9,
                0xAA,
                0xAB,
                0xAC,
                0xAD,
                0xAE,
                0xAF,
            ]
        )

        info = bytearray(
            [
                0xB0,
                0xB1,
                0xB2,
                0xB3,
                0xB4,
                0xB5,
                0xB6,
                0xB7,
                0xB8,
                0xB9,
                0xBA,
                0xBB,
                0xBC,
                0xBD,
                0xBE,
                0xBF,
                0xC0,
                0xC1,
                0xC2,
                0xC3,
                0xC4,
                0xC5,
                0xC6,
                0xC7,
                0xC8,
                0xC9,
                0xCA,
                0xCB,
                0xCC,
                0xCD,
                0xCE,
                0xCF,
                0xD0,
                0xD1,
                0xD2,
                0xD3,
                0xD4,
                0xD5,
                0xD6,
                0xD7,
                0xD8,
                0xD9,
                0xDA,
                0xDB,
                0xDC,
                0xDD,
                0xDE,
                0xDF,
                0xE0,
                0xE1,
                0xE2,
                0xE3,
                0xE4,
                0xE5,
                0xE6,
                0xE7,
                0xE8,
                0xE9,
                0xEA,
                0xEB,
                0xEC,
                0xED,
                0xEE,
                0xEF,
                0xF0,
                0xF1,
                0xF2,
                0xF3,
                0xF4,
                0xF5,
                0xF6,
                0xF7,
                0xF8,
                0xF9,
                0xFA,
                0xFB,
                0xFC,
                0xFD,
                0xFE,
                0xFF,
            ]
        )

        okm = bytearray(
            [
                0xB1,
                0x1E,
                0x39,
                0x8D,
                0xC8,
                0x03,
                0x27,
                0xA1,
                0xC8,
                0xE7,
                0xF7,
                0x8C,
                0x59,
                0x6A,
                0x49,
                0x34,
                0x4F,
                0x01,
                0x2E,
                0xDA,
                0x2D,
                0x4E,
                0xFA,
                0xD8,
                0xA0,
                0x50,
                0xCC,
                0x4C,
                0x19,
                0xAF,
                0xA9,
                0x7C,
                0x59,
                0x04,
                0x5A,
                0x99,
                0xCA,
                0xC7,
                0x82,
                0x72,
                0x71,
                0xCB,
                0x41,
                0xC6,
                0x5E,
                0x59,
                0x0E,
                0x09,
                0xDA,
                0x32,
                0x75,
                0x60,
                0x0C,
                0x2F,
                0x09,
                0xB8,
                0x36,
                0x77,
                0x93,
                0xA9,
                0xAC,
                0xA3,
                0xDB,
                0x71,
                0xCC,
                0x30,
                0xC5,
                0x81,
                0x79,
                0xEC,
                0x3E,
                0x87,
                0xC1,
                0x4C,
                0x01,
                0xD5,
                0xC1,
                0xF3,
                0x43,
                0x4F,
                0x1D,
                0x87,
            ]
        )

        actualOutput = HKDF(3).deriveSecrets(ikm, info, 82, salt=salt)
        self.assertEqual(okm, actualOutput)

    def test_vectorV3_(self):
        ikm = bytearray(
            [
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
            ]
        )

        salt = bytearray(
            [
                0x00,
                0x01,
                0x02,
                0x03,
                0x04,
                0x05,
                0x06,
                0x07,
                0x08,
                0x09,
                0x0A,
                0x0B,
                0x0C,
            ]
        )

        info = bytearray([0xF0, 0xF1, 0xF2, 0xF3, 0xF4, 0xF5, 0xF6, 0xF7, 0xF8, 0xF9])

        okm = bytearray(
            [
                0x6E,
                0xC2,
                0x55,
                0x6D,
                0x5D,
                0x7B,
                0x1D,
                0x81,
                0xDE,
                0xE4,
                0x22,
                0x2A,
                0xD7,
                0x48,
                0x36,
                0x95,
                0xDD,
                0xC9,
                0x8F,
                0x4F,
                0x5F,
                0xAB,
                0xC0,
                0xE0,
                0x20,
                0x5D,
                0xC2,
                0xEF,
                0x87,
                0x52,
                0xD4,
                0x1E,
                0x04,
                0xE2,
                0xE2,
                0x11,
                0x01,
                0xC6,
                0x8F,
                0xF0,
                0x93,
                0x94,
                0xB8,
                0xAD,
                0x0B,
                0xDC,
                0xB9,
                0x60,
                0x9C,
                0xD4,
                0xEE,
                0x82,
                0xAC,
                0x13,
                0x19,
                0x9B,
                0x4A,
                0xA9,
                0xFD,
                0xA8,
                0x99,
                0xDA,
                0xEB,
                0xEC,
            ]
        )

        actualOutput = HKDF(2).deriveSecrets(ikm, info, 64, salt=salt)
        self.assertEqual(okm, actualOutput)

==> omemo-dr-1.0.1.tar.gz: omemo-dr-1.0.1/tests/kdf/test_hkdf.py <==
import unittest

from omemo_dr.kdf.hkdf import HKDF


class HKDFTest(unittest.TestCase):
    def test_vector_v3(self):
        ikm = bytes(
            [
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
                0x0B,
            ]
        )

        salt = bytes(
            [
                0x00,
                0x01,
                0x02,
                0x03,
                0x04,
                0x05,
                0x06,
                0x07,
                0x08,
                0x09,
                0x0A,
                0x0B,
                0x0C,
            ]
        )

        info = bytes([0xF0, 0xF1, 0xF2, 0xF3, 0xF4, 0xF5, 0xF6, 0xF7, 0xF8, 0xF9])

        okm = bytes(
            [
                0x3C,
                0xB2,
                0x5F,
                0x25,
                0xFA,
                0xAC,
                0xD5,
                0x7A,
                0x90,
                0x43,
                0x4F,
                0x64,
                0xD0,
                0x36,
                0x2F,
                0x2A,
                0x2D,
                0x2D,
                0x0A,
                0x90,
                0xCF,
                0x1A,
                0x5A,
                0x4C,
                0x5D,
                0xB0,
                0x2D,
                0x56,
                0xEC,
                0xC4,
                0xC5,
                0xBF,
                0x34,
                0x00,
                0x72,
                0x08,
                0xD5,
                0xB8,
                0x87,
                0x18,
                0x58,
                0x65,
            ]
        )

        actual_output = HKDF(3).derive_secrets(ikm, info, 42, salt=salt)
        self.assertEqual(okm, actual_output)

    def test_vector_long_v3(self):
        ikm = bytes(
            [
                0x00,
                0x01,
                0x02,
                0x03,
                0x04,
                0x05,
                0x06,
                0x07,
                0x08,
                0x09,
                0x0A,
                0x0B,
                0x0C,
                0x0D,
                0x0E,
                0x0F,
                0x10,
                0x11,
                0x12,
                0x13,
                0x14,
                0x15,
                0x16,
                0x17,
                0x18,
                0x19,
                0x1A,
                0x1B,
                0x1C,
                0x1D,
                0x1E,
                0x1F,
                0x20,
                0x21,
                0x22,
                0x23,
                0x24,
                0x25,
                0x26,
                0x27,
                0x28,
                0x29,
                0x2A,
                0x2B,
                0x2C,
                0x2D,
                0x2E,
                0x2F,
                0x30,
                0x31,
                0x32,
                0x33,
                0x34,
                0x35,
                0x36,
                0x37,
                0x38,
                0x39,
                0x3A,
                0x3B,
                0x3C,
                0x3D,
                0x3E,
                0x3F,
                0x40,
                0x41,
                0x42,
                0x43,
                0x44,
                0x45,
                0x46,
                0x47,
                0x48,
                0x49,
                0x4A,
                0x4B,
                0x4C,
                0x4D,
                0x4E,
                0x4F,
            ]
        )

        salt = bytes(
            [
                0x60,
                0x61,
                0x62,
                0x63,
                0x64,
                0x65,
                0x66,
                0x67,
                0x68,
                0x69,
                0x6A,
                0x6B,
                0x6C,
                0x6D,
                0x6E,
                0x6F,
                0x70,
                0x71,
                0x72,
                0x73,
                0x74,
                0x75,
                0x76,
                0x77,
                0x78,
                0x79,
                0x7A,
                0x7B,
                0x7C,
                0x7D,
                0x7E,
                0x7F,
                0x80,
                0x81,
                0x82,
                0x83,
                0x84,
                0x85,
                0x86,
                0x87,
                0x88,
                0x89,
                0x8A,
                0x8B,
                0x8C,
                0x8D,
                0x8E,
                0x8F,
                0x90,
                0x91,
                0x92,
                0x93,
                0x94,
                0x95,
                0x96,
                0x97,
                0x98,
                0x99,
                0x9A,
                0x9B,
                0x9C,
                0x9D,
                0x9E,
                0x9F,
                0xA0,
                0xA1,
                0xA2,
                0xA3,
                0xA4,
                0xA5,
                0xA6,
                0xA7,
                0xA8,
                0xA9,
                0xAA,
                0xAB,
                0xAC,
                0xAD,
                0xAE,
                0xAF,
            ]
        )

        info = bytes(
            [
                0xB0,
                0xB1,
                0xB2,
                0xB3,
                0xB4,
                0xB5,
                0xB6,
                0xB7,
                0xB8,
                0xB9,
                0xBA,
                0xBB,
                0xBC,
                0xBD,
                0xBE,
                0xBF,
                0xC0,
                0xC1,
                0xC2,
                0xC3,
                0xC4,
                0xC5,
                0xC6,
                0xC7,
                0xC8,
                0xC9,
                0xCA,
                0xCB,
                0xCC,
                0xCD,
                0xCE,
                0xCF,
                0xD0,
                0xD1,
                0xD2,
                0xD3,
                0xD4,
                0xD5,
                0xD6,
                0xD7,
                0xD8,
                0xD9,
                0xDA,
                0xDB,
                0xDC,
                0xDD,
                0xDE,
                0xDF,
                0xE0,
                0xE1,
                0xE2,
                0xE3,
                0xE4,
                0xE5,
                0xE6,
                0xE7,
                0xE8,
                0xE9,
                0xEA,
                0xEB,
                0xEC,
                0xED,
                0xEE,
                0xEF,
                0xF0,
                0xF1,
                0xF2,
                0xF3,
                0xF4,
                0xF5,
                0xF6,
                0xF7,
                0xF8,
                0xF9,
                0xFA,
                0xFB,
                0xFC,
                0xFD,
                0xFE,
                0xFF,
            ]
        )

        okm = bytes(
            [
                0xB1,
                0x1E,
                0x39,
                0x8D,
                0xC8,
                0x03,
                0x27,
                0xA1,
                0xC8,
                0xE7,
                0xF7,
                0x8C,
                0x59,
                0x6A,
                0x49,
                0x34,
                0x4F,
                0x01,
                0x2E,
                0xDA,
                0x2D,
                0x4E,
                0xFA,
                0xD8,
                0xA0,
                0x50,
                0xCC,
                0x4C,
                0x19,
                0xAF,
                0xA9,
                0x7C,
                0x59,
                0x04,
                0x5A,
                0x99,
                0xCA,
                0xC7,
                0x82,
                0x72,
                0x71,
                0xCB,
                0x41,
                0xC6,
                0x5E,
                0x59,
                0x0E,
                0x09,
                0xDA,
                0x32,
                0x75,
                0x60,
                0x0C,
                0x2F,
                0x09,
                0xB8,
                0x36,
                0x77,
                0x93,
                0xA9,
                0xAC,
                0xA3,
                0xDB,
                0x71,
                0xCC,
                0x30,
                0xC5,
                0x81,
                0x79,
                0xEC,
                0x3E,
                0x87,
                0xC1,
                0x4C,
                0x01,
                0xD5,
                0xC1,
                0xF3,
                0x43,
                0x4F,
                0x1D,
                0x87,
            ]
        )

        actual_output = HKDF(3).derive_secrets(ikm, info, 82, salt=salt)
        self.assertEqual(okm, actual_output)
